@@ -1,7 +1,8 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::Value;
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RUN_AGAIN, RunAgain};
+
 #[derive(FlowImpl)]
 /// Route data to one or another based on a boolean control value.
 #[derive(Debug)]
@@ -21,4 +22,4 @@ impl Implementation for Route {
 
         (Some(Value::Object(output_map)), RUN_AGAIN)
     }
-}
\ No newline at end of file
+}
