@@ -1,7 +1,8 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::Value;
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RunAgain, RUN_AGAIN};
+
 #[derive(FlowImpl)]
 /// Control the flow of data (flow or disapear it) based on a boolean control value.
 #[derive(Debug)]
@@ -18,4 +19,4 @@ impl Implementation for Tap {
 
         (value, RUN_AGAIN)
     }
-}
\ No newline at end of file
+}
