@@ -1,7 +1,8 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::{json, Value};
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RunAgain, RUN_AGAIN};
+
 #[derive(FlowImpl)]
 /// Split a string into (possibly) its parts, based on a separator.
 #[derive(Debug)]
@@ -22,9 +23,10 @@ impl Implementation for OrderedSplit {
 
 #[cfg(test)]
 mod test {
-    use flow_impl::Implementation;
     use serde_json::json;
 
+    use flowcore::Implementation;
+
     #[test]
     fn simple() {
         let string = json!("the quick brown fox jumped over the lazy dog");
@@ -38,4 +40,4 @@ mod test {
 
         assert_eq!(array.len(), 9);
     }
-}
\ No newline at end of file
+}
